function customDetection_MANUALFILE(fs, minR, maxR, step, minL, maxL)
%INPUTS: 
%fs - sampling frequency (250?)
%minR - min detection range in Hz
%maxR - max detection range in Hz
%minL - min 'spindle' length in seconds
%maxL - max 'spindle' length in seconds

%convert min/max length to samples
minL = minL*fs;
maxL = maxL*fs;

[allFiles, pathAll] = uigetfile('*.txt', 'MultiSelect', 'on');

%organise to find night 1 - so that they can be processed first
for i = 1:numel(allFiles)
    segmentString = strsplit(allFiles{i}, '_');
    finalString = segmentString{end};
    periodString = {finalString(1:6)};
    night1Flag(i) = ismember(periodString, 'Night1');
end

reorderedFiles = [allFiles(night1Flag) allFiles(~night1Flag)]';
reorderedFlag = [night1Flag(night1Flag) night1Flag(~night1Flag)]';
    
for i = 1:numel(reorderedFiles)
    file = reorderedFiles{i}
    pathF = pathAll;
    if reorderedFlag(i) == 1
        threshImport = 0;
        hardT = [];
        softT = [];
        importFile = file;
    else
        threshImport = 1;
        segmentString = strsplit(file, '_');
        importFile = [segmentString{1} '_' segmentString{2} '_' segmentString{3} '_' segmentString{4} '_Night1(2012-0647)_range5to16_spFound.mat'];
        importedData = load('-mat', importFile);
        softT = importedData.spFound.softT;
        hardT = importedData.spFound.hardT;
        clear importedData;
    end


    %import data
    [d2.Data.Raw, Info] =  importSheepData(file, pathF, fs);
    %[d2.Data.Raw, Info] =  importSheepDataASSTRING(file, pathF, fs);
    %record where thresholds were from
    Info.thresholdsFrom = importFile;
    %calc CWT
    d2.Data.CWT = getCWT(d2, fs, minR, maxR, step);
    %find spindles
    [spFound, spFound.hardT, spFound.softT] = spFind(d2, threshImport, hardT, softT);
    %log if new thresholds were used
    spFound.threshImport = threshImport;
    spFound.info = Info;
    %investigate spindle details
    %spFound = reviewSpindles(spFound, d2, fs, minR, maxR);
    spFound = reviewSpindles(spFound, d2, fs, minR, maxR);
    %mark spindles for removal
    spFound = flagSpindles(spFound, minL, maxL);

    save([file(1:end-4) '_range', num2str(minR), 'to' num2str(maxR), '_spFound.mat'], 'spFound')
    disp(['saved ' file(1:end-4) '_spFound.mat']);
    clear spFound
    clear d2
    clear Info
end

end

