function spFound = reviewSpindles(spFound, d, fs, minR, maxR)
%perform an FFT on every spindle. 
%find the peak frequency, its power, and some other bits too...

for sp = 1:numel(spFound.spStart)
    %get spindle start, end times, and channel
    spStart = spFound.spStart(sp);
    spEnd = spFound.spEnd(sp);
    spChan = spFound.chan(sp);
    %collect spindle
    spWave = d.Data.Raw(spChan, spStart:spEnd);
    spFound.raw(sp).wave = spWave;
    spWave(isnan(spWave))= 0;
    %get difference between every sample  point
    dWave = abs(diff(spWave));
    dMean = mean(dWave);
    dMax = max(dWave);
    %create a score to assess how much this spindle differs from the mean -
    %to be used to see if it might be an atrifact
    spFound.Xscore(sp) = (dMean + dMax)/dMean;

    %do FFT
    actualSpindle =spWave - mean(spWave);
    NFFT = 1024;
    L=length(actualSpindle);
    winVec = hann(L);  
    X2=fft(actualSpindle.*winVec',NFFT);    
    Px2=X2.*conj(X2)/(NFFT*L); 
    fVals=fs*(0:NFFT/2-1)/NFFT;
    fftSpectrum = real(Px2(1:NFFT/2));
    rangeTop = find(fVals> maxR);
    rangeTop = rangeTop(1);
    rangeBottom = find(fVals<minR);
    rangeBottom = rangeBottom(end);
    %power under 5 Hz
    spFound.lowPwr(sp) = sum(fftSpectrum(1:rangeBottom));
    %ratio of power over  30 Hz to what is in the spindle range. 
    %spindle range is 5 to 18.
    spFound.spPwr(sp) =  sum(fftSpectrum(rangeBottom:rangeTop));
    spFound.highPwr(sp) = sum(fftSpectrum(rangeTop:end));
    spFound.highRatio(sp) = (spFound.spPwr(sp) + spFound.highPwr(sp) )/spFound.highPwr(sp) ;
    [p, i] = findpeaks(fftSpectrum(rangeBottom:rangeTop));

    if isempty(i) ==1
        %if there was no peak, then make a note!, and just collect the max
        %power, and find the location it, to be used ins tead
        [p2, i2] = max(fftSpectrum(rangeBottom:rangeTop));
        spFound.noPeak(sp) = 1;
    else
        spFound.noPeak(sp) = 0;
        [p2, i2] = max(p);
        i2 = i(i2);
    end
    %safe info
    spFound.peakFreq(sp) =   fVals(i2- 1 + rangeBottom);
    spFound.peakFreqPwr(sp) = p2;
%     
sp
end
spFound.spSpectrumFreqs = fVals;
end
