function [spFound, hardT, softT] = spFind(d, threshImport, hardT, softT)

%populate structure with some empty fields
spFound = struct(...
    'spStart', [],...
    'spEnd', [],...
    'spLength', [],...
    'chan', [],...
    'pwrCWTRangeSum', [],...
    'pwrCWTRangePeak', []);

for c = 1:8
    %get CWT power data.
    cwtP = d.Data.CWT(c, :);
    %populate 'found' vector with zeros
    found = zeros(1, length(cwtP));
    %find the peaks in the CWT power
    [pks,locs,w,p]= findpeaks(cwtP);
    %I only want peaks with prominences over the soft threshold
    %check to see if importing thresholds from a different file, otherwise
    %use 1.8 and 1.2 of the mean CWT power for the hard and soft thresholds
    if threshImport == 0
        hardThreshold = nanmean(cwtP)*1.8;
        hardT(c) = hardThreshold;
        softThreshold = nanmean(cwtP)*1.2;
        softT(c) = softThreshold;
    else
        hardThreshold = hardT(c);
        softThreshold = softT(c);
    end
    passSp = find(p > hardThreshold) ;
    for spi = 1:length(passSp)
        windowStart = locs(passSp(spi)) - 2500;
        windowEnd = locs(passSp(spi)) + 2500;
        %peak location is the centre, unless the window is lopsided
        peakLoc = 2500;
        if windowStart < 1
            peakLoc = 2500 + windowStart;
            windowStart = 1;
        end
        if windowEnd > length(cwtP)
            windowEnd = length(cwtP);
        end

        thresh = pks(passSp(spi)) - p(passSp(spi))*0.8;

        if thresh < softThreshold
            %if the threshold is less than the global soft threshold then I'm
            %going to have problems 
            %so force it to be equal to the soft threshold in this case...
            thresh = softThreshold;
        end

        pkOverThresh = cwtP(windowStart:windowEnd)> thresh;
        %get the difference
        pkDiff = diff([0 pkOverThresh 0]);
        %find the nearest starts/ends to the peak
        pkStarts = find(pkDiff == 1);
        pkEnds = find(pkDiff == -1);
        locs(passSp(spi));
        %remove any starts after the peak
        pkStarts(pkStarts > peakLoc) = [];
        [m, i] = min(abs((pkStarts + windowStart) - locs(passSp(spi))));
        pkStart = pkStarts(i) - 1 + windowStart;
        %remove any ends before the peak
        pkEnds(pkEnds < peakLoc) = [];
        [m, i] = min(abs((pkEnds + windowStart) - locs(passSp(spi))));
        pkEnd = pkEnds(i) - 1 + windowStart;
        pkLength = pkEnd - pkStart;
        found(pkStart:pkEnd) = 1;
    end

    spStarts = find(diff([0 found 0]) == 1);
    spEnds = find(diff([0 found 0]) == -1)-1;
    spLengths = spEnds - spStarts;
    spPower = [];
    spPowerPeak = [];
    for i = 1:length(spStarts)
        spPower(i) = sum(cwtP(spStarts(i):spEnds(i)));
        spPowerPeak(i) = max(cwtP(spStarts(i):spEnds(i)));
    end

    %pad the end of found with zeros to full size (though I no longer save
    %this to reduce memory usage)
    found(end+1:numel(cwtP)) = 0;
    spFound.spStart = [spFound.spStart;  spStarts'];
    spFound.spEnd = [spFound.spEnd; spEnds'];
    spFound.spLength = [spFound.spLength; spLengths'];
    spFound.chan = [spFound.chan; c.*ones(length(spStarts), 1)];
    spFound.pwrCWTRangeSum = [spFound.pwrCWTRangeSum; spPower'];
    spFound.pwrCWTRangePeak = [spFound.pwrCWTRangePeak; spPowerPeak'];
    clear spStarts spEnds spLengths spPower spPowerPeak found
end


end




